# README

This is the README for the **Notes** portion of this data request. The term **Notes** is sometimes used interchangeably with **clinical text**, **clinical notes**, or **orders**, but the preferred ontology is as follows:

```text
Structured Data
Unstructured Data
└── Clinical Text
    ├── Notes
    └── Orders
        ├── Order Impression
        ├── Order Narrative
        └── Order Results
```

The identifier for the clinical text corresponds to the types below

| Clinical Text Type | Clinical Text Identifier |
| ------------------ | ------------------------ |
| Notes              | Linkage Note ID          |
| Orders             | Order Key                |
